#!/bin/sh

iptables -F
iptables -F -t nat
iptables -X
iptables -X -t nat

iptables -P INPUT ACCEPT
iptables -P FORWARD ACCEPT
iptables -P OUTPUT ACCEPT
iptables -P PREROUTING ACCEPT -t nat
iptables -P POSTROUTING ACCEPT -t nat

HOTSYNC_PORT=14238
SYN_FLOOD_RATE=20/s
SYN_FLOOD_BURST=40
IPSEC_IKE_RATE=2/s
IPSEC_IKE_BURST=4
IPSEC_PORT=500
CHARGEN_PORT=19
ECHO_PORT=7
QUOTEOFDAY_PORT=17
TIMEOFDAY_PORT=13
FTP_DATA_PORT=20
FTP_CNTRL_PORT=21
YAHOO_DOS_PORT=5010
FRAGGLE_LIMIT=2/s
FRAGGLE_LIMIT_BURST=4
SMTP_PORT=25
WEB_PORT=80
ICQ_PORT=80
WINNUKE_PORTS=137,138,139
PSD_THRESHOLD=30
PSD_DELAY=10
PSD_LOPORT_WEIGHT=5
PSD_HIPORT_WEIGHT=2


#Hotsync manager Dos
iptables -A PREROUTING -t nat -p tcp --dport $HOTSYNC_PORT -j DNAT --to 10.10.10.10
iptables -A FORWARD -p tcp --dport $HOTSYNC_PORT -j REJECT --reject-with icmp-port-unreachable

#TCP Hijacking
iptables -A PREROUTING -t nat -p tcp -m ipv4options --ssrr -j DROP
iptables -A PREROUTING -t nat -p tcp -m ipv4options --lsrr -j DROP

#TCP Syn Flooding
iptables -A FORWARD -p tcp --tcp-flags ALL SYN -m limit ! --limit $SYN_FLOOD_RATE --limit-burst $SYN_FLOOD_BURST -j DROP

#IPSec IKE Check
iptables -A PREROUTING -t nat -p udp --dport $IPSEC_PORT -m limit --limit $IPSEC_IKE_RATE --limit-burst $IPSEC_IKE_BURST -j DROP
	#Dnat if above limit is not hit
	iptables -A PREROUTING -t nat -p udp --dport $IPSEC_PORT -j DNAT --to 10.10.10.10

#UDP Port LoopBack
iptables -A PREROUTING -t mangle -p udp -m multiport --sports 7,13,17,19 -j MARK --set-mark 7131719
iptables -A PREROUTING -t nat -p udp -m multiport --dports 7,13,17,19 -m mark --mark 7131719 -j DROP
	#Dnat if above limit is not hit
	#iptables -A PREROUTING -t nat -p udp -m multiport --dports $CHARGEN_PORT,$ECHO_PORT,$TIMEOFDAY_PORT,$QUOTEOFDAY_PORT -j DNAT --to 10.10.10.10

#FTP Port Restricted
iptables -A PREROUTING -t nat -i nas+ -p tcp --dport $FTP_CNTRL_PORT -j DNAT --to 10.10.10.10
iptables -A POSTROUTING -t nat -o nas+ -p tcp --dport $FTP_CNTRL_PORT -j MASQUERADE
iptables -A FORWARD -p tcp -m ifxattack --name ftp_port -j REJECT --reject-with tcp-reset

#Yahoo Messenger DoS
iptables -A PREROUTING -t nat -p tcp --dport $YAHOO_DOS_PORT -j DNAT --to 10.10.10.10
iptables -A FORWARD -p tcp --dport $YAHOO_DOS_PORT -j REJECT --reject-with tcp-reset

#Fraggle
iptables -A PREROUTING -t nat -p udp -m multiport --dports $CHARGEN_PORT,$ECHO_PORT,$TIMEOFDAY_PORT,$QUOTEOFDAY_PORT -m addrtype --dst-type BROADCAST -j DROP
iptables -A PREROUTING -t nat -p udp -m multiport --sports $CHARGEN_PORT,$ECHO_PORT,$TIMEOFDAY_PORT,$QUOTEOFDAY_PORT -m limit --limit $FRAGGLE_LIMIT --limit-burst $FRAGGLE_LIMIT_BURST -j DROP
	#Dnat if above is not hit
	iptables -A PREROUTING -t nat -p udp -m multiport --dports $CHARGEN_PORT,$ECHO_PORT,$TIMEOFDAY_PORT,$QUOTEOFDAY_PORT -j DNAT --to 10.10.10.10

#Port Scan
iptables -A PREROUTING -t nat -m psd --psd-weight-threshold $PSD_THRESHOLD --psd-delay-threshold $PSD_DELAY --psd-lo-ports-weight $PSD_LOPORT_WEIGHT --psd-hi-ports-weight $PSD_HIPORT_WEIGHT -j DROP

#Christmas tree
iptables -A PREROUTING -t nat -p tcp --tcp-flags ALL ALL -j DROP
iptables -A PREROUTING -t nat -p tcp --tcp-flags ALL NONE -j DROP

#Exchanged Malformed MIME
iptables -A PREROUTING -t nat -p tcp --dport $SMTP_PORT -j DNAT --to 10.10.10.10
iptables -A FORWARD -p tcp --dport $SMTP_PORT -m ifxattack --name malformed_mime -j REJECT --reject-with tcp-reset

#Code RedII
iptables -A PREROUTING -t nat -p tcp --dport $WEB_PORT -j DNAT --to 10.10.10.10
iptables -A FORWARD -p tcp --dport $WEB_PORT -m ifxattack --name code_redII -j REJECT --reject-with tcp-reset

#Code RedI
iptables -A PREROUTING -t nat -p tcp --dport $WEB_PORT -j DNAT --to 10.10.10.10
iptables -A FORWARD -p tcp --dport $WEB_PORT -m ifxattack --name code_redI -j REJECT --reject-with tcp-reset

#Land Attack
iptables -A PREROUTING -t nat -m ifxattack --name land_attack -j DROP

#ICQ DoS
iptables -A PREROUTING -t nat -p tcp --dport $ICQ_PORT -j DNAT --to 10.10.10.10
iptables -A FORWARD -p tcp --dport $ICQ_PORT -m ifxattack --name icq_dos -j REJECT --reject-with tcp-reset

#Winnuke
iptables -A PREROUTING -t nat -p tcp -m multiport --dports $WINNUKE_PORTS -j DNAT --to 10.10.10.10
iptables -A FORWARD -p tcp --tcp-flags URG URG -m multiport --dports $WINNUKE_PORTS -j REJECT --reject-with tcp-reset 

#UDP Bomb
iptables -A PREROUTING -t nat -p udp -m ifxattack --name udp_bomb -j DROP

#ICMP MASQUERADE
iptables -A POSTROUTING -t nat -p icmp -o nas+ -j MASQUERADE
iptables -A PREROUTING -t nat -i nas+ -p icmp -j DNAT --to 10.10.10.10
